@@ -67,6 +67,8 @@ function() {
     q.seq <- eval(expression(q.seq), parent.frame())
     if (!is.vector(q.seq))
       ErrorMessage("q.seq must be a numeric vector.", q.seq)
+    if (length(q.seq) < 2)
+      ErrorMessage("q.seq must contain at least 2 values.", q.seq)
   }
 
   # alpha
@@ -82,9 +84,9 @@ function() {
   if (!is.na(names(Args["Alpha"]))) {
     Alpha <- eval(expression(Alpha), parent.frame())
     if (!is.numeric(Alpha))
-      ErrorMessage("Alpha must be a number.", Alpha)    
+      ErrorMessage("Alpha must be a number.", Alpha)
     if (Alpha <= 0 | Alpha >= 1)
-      ErrorMessage("Alpha must be strictly between 0 and 1.", Alpha)    
+      ErrorMessage("Alpha must be strictly between 0 and 1.", Alpha)
   }
 
   # BootstrapMethod 
@@ -128,12 +130,14 @@ function() {
   # n
   if (!is.na(names(Args["n"]))) {
     n <- eval(expression(n), parent.frame())
-    if (!is.numeric(n) | length(n)!=1)
-      ErrorMessage("n must be a number.", n)
-    if (any(n < 1))
-      ErrorMessage("n must be at least 1.", n)
-    if (as.integer(n) != n)
-      ErrorMessage("n must be an integer.", n)
+    if (!is.null(n)) {
+      if (!is.numeric(n) | length(n)!=1)
+        ErrorMessage("n must be a number.", n)
+      if (any(n < 1))
+        ErrorMessage("n must be at least 1.", n)
+      if (as.integer(n) != n)
+        ErrorMessage("n must be an integer.", n)
+    }
   }
   
   # Normalize 
@@ -258,6 +262,13 @@ function() {
     }
   }
   
+  # PhyloDetails 
+  if (!is.na(names(Args["PhyloDetails"]))) {
+    PhyloDetails <- eval(expression(PhyloDetails), parent.frame())
+    if (!is.logical(PhyloDetails))
+      ErrorMessage("PhyloDetails must be TRUE or FALSE.", PhyloDetails)
+  }
+  
   # r
   if (!is.na(names(Args["r"]))) {
     r <- eval(expression(r), parent.frame())
@@ -269,7 +280,7 @@ function() {
       ErrorMessage("r must be an integer.", r)
   }
 
-    # sd
+  # sd
   if (!is.na(names(Args["sd"]))) {
     sd <- eval(expression(sd), parent.frame())
     if (!is.numeric(sd) | length(sd)!=1)
@@ -343,6 +354,17 @@ function() {
       ErrorMessage("S must be an integer.", S)
   }
   
+  # SampleCoverage 
+  if (!is.na(names(Args["SampleCoverage"]))) {
+    SampleCoverage <- eval(expression(SampleCoverage), parent.frame())
+    if (!is.null(SampleCoverage)) {
+      if (!is.numeric(SampleCoverage))
+        ErrorMessage("SampleCoverage must be a number.", SampleCoverage)
+      if (SampleCoverage <= 0 | SampleCoverage >= 1)
+        ErrorMessage("SampleCoverage must be strictly between 0 and 1.", SampleCoverage)
+    }
+  }
+  
   # SimulatedValues
   if (!is.na(names(Args["SimulatedValues"]))) {
     SimulatedValues <- eval(expression(SimulatedValues), parent.frame())
