@@ -4,46 +4,63 @@ function(q = 1, MC, Biased = TRUE, Correction = "Best", Tree = NULL, Normalize =
   if (CheckArguments)
     CheckentropartArguments()
   
-  # Preprocess the tree
+  # Preprocess the tree. Height is 1 by default, including species neutral diversity.
+  Height <- 1
   ppTree <- Preprocess.Tree(Tree)
-  if (Normalize) {
-    Height <- 1
-  } else {
+  if (!is.null(ppTree$Height) & !Normalize) {
     Height <- ppTree$Height
-  }  
-
-  # Alpha and beta entropy of communities
-  if (Biased) {
-    AlphaEntropy <- AlphaEntropy(MC, q, "None", ppTree, Normalize, Z, CheckArguments=FALSE)
-    GammaEntropy <- GammaEntropy(MC, q, "None", ppTree, Normalize, Z, CheckArguments=FALSE)
-    BetaEntropy  <- BetaEntropy (MC, q, "None", ppTree, Normalize, Z, CheckArguments=FALSE)
-  } else {
-    AlphaEntropy <- AlphaEntropy(MC, q, Correction, ppTree, Normalize, Z, CheckArguments=FALSE)
-    GammaEntropy <- GammaEntropy(MC, q, Correction, ppTree, Normalize, Z, CheckArguments=FALSE)
-    # beta is calculated as gamma-alpha to ensure continuity. Community beta entropy is not calculated.
-    BetaEntropy  <- list(Communities = NA, Total = GammaEntropy - AlphaEntropy$Total)      
   }
+  
+  # Correction methods
+  if (Biased) Correction = "None"
+  if (!is.IntValues(MC$Ns)) {
+    # Only ChaoShen, Marcon (HCDT only, not Similarity-based) or None are acceptable if MC$Ns are not integers.
+    if (Correction == "Best") {
+      if (is.null(Z)) {
+        Correction <- "Marcon"
+      } else {
+        Correction <- "ChaoShen"
+      }
+    }
+  }
+
+  # Alpha and beta entropy of communities. PhyloDetails=TRUE forces the return of a is.PhyloValue if phyloentropy is calculated.
+  GammaE <- GammaEntropy(MC, q, Correction, ppTree, Normalize, Z, PhyloDetails=TRUE, CheckArguments=FALSE)
+  # Alpha entropy is estimated with the same correction as Gamma
+  if (is.PhyloValue(GammaE)) {
+    # Phyloentropy. GammaEntropy returned a PhyloValue with Corrections along the tree
+    AlphaCorrection <- GammaE$Corrections
+    # Make GammaE a number again
+    GammaE <- GammaE$Total
+  } else {
+    # GammaEntropy is a named number
+    AlphaCorrection <- names(GammaE)
+  }
+  AlphaE <- AlphaEntropy(MC, q, AlphaCorrection, ppTree, Normalize, Z, CheckArguments=FALSE)
+  # beta is calculated as gamma-alpha to ensure continuity. Community beta entropy is not calculated.
+  BetaE  <- list(Communities = NA, Total = GammaE - AlphaE$Total)      
+
   # Total Diversities
-  AlphaDiversity <- expq(AlphaEntropy$Total / Height, q) * Height
-  GammaDiversity <- expq(GammaEntropy / Height, q) * Height
-  BetaDiversity  <- GammaDiversity / AlphaDiversity
-    # equals: expq(BetaEntropy$Total / Height / (1 - (q-1)*AlphaEntropy$Total/Height), q) 
+  AlphaD <- expq(AlphaE$Total / Height, q) * Height
+  GammaD <- expq(GammaE / Height, q) * Height
+  BetaD  <- GammaD / AlphaD
+    # equals: expq(BetaE$Total / Height / (1 - (q-1)*AlphaE$Total/Height), q) 
   
   DivPart <- (list(
     MetaCommunity = ArgumentOriginalName(MC),
     Order = q, 
     Biased = Biased, 
-    Correction = Correction,
+    Correction = AlphaCorrection,
     Normalized = Normalize,
-    TotalAlphaDiversity = AlphaDiversity, 
-    TotalBetaDiversity = BetaDiversity, 
-    GammaDiversity = GammaDiversity, 
-    CommunityAlphaDiversities = expq(AlphaEntropy$Communities / Height, q) * Height, 
-    TotalAlphaEntropy = AlphaEntropy$Total, 
-    TotalBetaEntropy = BetaEntropy$Total, 
-    GammaEntropy = GammaEntropy, 
-    CommunityAlphaEntropies = AlphaEntropy$Communities, 
-    CommunityBetaEntropies = BetaEntropy$Communities
+    TotalAlphaDiversity = AlphaD,
+    TotalBetaDiversity = BetaD,
+    GammaDiversity = GammaD,
+    CommunityAlphaDiversities = expq(AlphaE$Communities / Height, q) * Height,
+    TotalAlphaEntropy = AlphaE$Total,
+    TotalBetaEntropy = BetaE$Total,
+    GammaEntropy = GammaE,
+    CommunityAlphaEntropies = AlphaE$Communities,
+    CommunityBetaEntropies = BetaE$Communities
     ))
   if(!is.null(Tree))
     DivPart$Tree <- ArgumentOriginalName(Tree)
